summaryrefslogtreecommitdiffstats
path: root/tdewallet/client/tdewallet.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdewallet/client/tdewallet.h')
-rw-r--r--tdewallet/client/tdewallet.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdewallet/client/tdewallet.h b/tdewallet/client/tdewallet.h
index fa5dbcbb2..e9bb65cec 100644
--- a/tdewallet/client/tdewallet.h
+++ b/tdewallet/client/tdewallet.h
@@ -38,7 +38,7 @@
class DCOPRef;
/** Namespace collecting all the Wallet-related classes. */
-namespace KWallet {
+namespace TDEWallet {
/**
* KDE Wallet
@@ -55,14 +55,14 @@ class TDEIO_EXPORT Wallet : public TQObject, public DCOPObject {
Q_OBJECT
protected:
/**
* Construct a KWallet object.
* @internal
* @param handle The handle for the wallet.
* @param name The name of the wallet.
*/
Wallet(int handle, const TQString& name);
/**
* Copy a KWallet object.
* @internal
*/
Wallet(const Wallet&);
@@ -71,7 +71,7 @@ class TDEIO_EXPORT Wallet : public TQObject, public DCOPObject {
enum EntryType { Unknown=0, Password, Stream, Map, Unused=0xffff };
/**
* Destroy a KWallet object. Closes the wallet.
*/
virtual ~Wallet();
@@ -55,14 +55,14 @@ class TDEIO_EXPORT Wallet : public TQObject, public DCOPObject {
protected:
/**
- * Construct a KWallet object.
+ * Construct a TDEWallet object.
* @internal
* @param handle The handle for the wallet.
@@ -55,14 +55,14 @@ class TDEIO_EXPORT Wallet : public TQObject, public DCOPObject {
Wallet(int handle, const TQString& name);
/**
- * Copy a KWallet object.
+ * Copy a TDEWallet object.
* @internal
*/
@@ -71,7 +71,7 @@ class TDEIO_EXPORT Wallet : public TQObject, public DCOPObject {
enum EntryType { Unknown=0, Password, Stream, Map, Unused=0xffff };
/**
- * Destroy a KWallet object. Closes the wallet.
+ * Destroy a TDEWallet object. Closes the wallet.
*/
virtual ~Wallet();